==> qcomicbook_0.3.4.orig.tar.gz: qcomicbook-0.3.4/src/bookmarks.cpp <==
/*
 * This file is a part of QComicBook.
 *
 * Copyright (C) 2005-2006 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * QComicBook is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "bookmarks.h"
#include "cbsettings.h"
#include <qpopupmenu.h>
#include <qfile.h>
#include <qdir.h>
#include <qtextstream.h>

using namespace QComicBook;

Bookmarks::Bookmarks(QPopupMenu *menu): bmenu(menu), changed(false)
{
	blist.setAutoDelete(true);
	fname = ComicBookSettings::bookmarksDir() + "/bookmarks";
}

Bookmarks::~Bookmarks()
{
}

bool Bookmarks::load()
{
	if (fname.isEmpty())
		return false;
	QFile f(fname);
	if (f.open(IO_ReadOnly))
	{
		QTextStream str(&f);
		while (!str.atEnd())
		{
			QString name = str.readLine();
			if (str.atEnd())
				break;
			int page = str.readLine().toInt();
			set(name, page);
		}
		f.close();
	}
	return false;
}

bool Bookmarks::save()
{
	if (!changed)
		return true;
	if (fname.isEmpty())
		return false;

	QFile f(fname);
	if (f.open(IO_WriteOnly))
	{
		QTextStream str(&f);
		for (Bookmark *b = blist.first(); b; b = blist.next())
			str << b->getName() << endl << b->getPage() << endl;
		f.close();
		return true;
	}
	return false;
}

void Bookmarks::set(const QString &cbname, int page)
{
	int id;
	for (Bookmark *b = blist.first(); b; b = blist.next())
		if ((b->getName() == cbname))
		{
			if (b->getPage() == page) //same page, do nothing
				return;
			id = b->getId();
			bmenu->removeItem(id);
			bmap.remove(id);
			b->setName(cbname);
			b->setPage(page);
			id = bmenu->insertItem(b->menuItemName());
			b->setId(id);
			bmap.insert(id, b);
			changed = true;
			return;
		}
	Bookmark *b = new Bookmark(cbname, page);
	blist.append(b);
	id = bmenu->insertItem(b->menuItemName());
	b->setId(id);
	bmap.insert(id, b);
	changed = true;
	return;
}

bool Bookmarks::remove(const QString &cbname)
{
	for (Bookmark *b = blist.first(); b; b = blist.next())
		if ((b->getName() == cbname))
		{
			bmenu->removeItem(b->getId());
			bmap.remove(b->getId());
			blist.remove();
			return true;
		}
	return false;
}

bool Bookmarks::remove(int id)
{
	if (bmap.contains(id))
	{
		Bookmark *b = bmap[id];
		bmenu->removeItem(id);
		bmap.remove(id);
		blist.remove(b);
		changed = true;
	}
}

bool Bookmarks::get(int id, Bookmark &b)
{
	if (bmap.contains(id))
	{
		b = *bmap[id];
		return true;
	}
	return false;
}

QValueList<Bookmark> Bookmarks::get()
{
	QValueList<Bookmark> res;
	for (Bookmark *b = blist.first(); b; b = blist.next())
		res.push_back(*b);
	return res;
}

bool Bookmarks::exists(const QString &cbname)
{
	for (Bookmark *b = blist.first(); b; b = blist.next())
		if (b->getName() == cbname)
			return true;
	return false;
}

==> qcomicbook_0.4.0.orig.tar.gz: qcomicbook-0.4.0/src/bookmarks.cpp <==
/*
 * This file is a part of QComicBook.
 *
 * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * QComicBook is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "bookmarks.h"
#include "cbsettings.h"
#include <QMenu>
#include <QFile>
#include <QDir>
#include <QTextStream>

using namespace QComicBook;

Bookmarks::Bookmarks(QMenu *menu): bmenu(menu), changed(false)
{
	fname = ComicBookSettings::bookmarksDir() + "/bookmarks";
}

Bookmarks::~Bookmarks()
{
}

bool Bookmarks::load()
{
	if (fname.isEmpty())
		return false;
	QFile f(fname);
	if (f.open(QIODevice::ReadOnly))
	{
		QTextStream str(&f);
		while (!str.atEnd())
		{
			QString name = str.readLine();
			if (str.atEnd())
				break;
			int page = str.readLine().toInt();
			set(name, page);
		}
		f.close();
	}
	return false;
}

bool Bookmarks::save()
{
	if (!changed)
		return true;
	if (fname.isEmpty())
		return false;

	QFile f(fname);
	if (f.open(QIODevice::WriteOnly))
	{
		QTextStream str(&f);
		foreach (Bookmark *b, blist)
			str << b->getName() << endl << b->getPage() << endl;
		f.close();
		return true;
	}
	return false;
}

void Bookmarks::set(const QString &cbname, int page)
{
	QAction *action;
	foreach (Bookmark *b, blist)
	{
		if ((b->getName() == cbname))
		{
			if (b->getPage() == page) //same page, do nothing
				return;
			action = b->getId();
			bmenu->removeAction(action);
			bmap.remove(action);
			b->setName(cbname);
			b->setPage(page);
			action = bmenu->addAction(b->menuItemName());
			b->setId(action);
			bmap.insert(action, b);
			changed = true;
			return;
		}
	}
	Bookmark *b = new Bookmark(cbname, page);
	blist.append(b);
	action = bmenu->addAction(b->menuItemName());
	b->setId(action);
	bmap.insert(action, b);
	changed = true;
	return;
}

bool Bookmarks::remove(const QString &cbname)
{
	foreach (Bookmark *b, blist)
	{
		if ((b->getName() == cbname))
		{
			bmenu->removeAction(b->getId());
			bmap.remove(b->getId());
			int idx = blist.indexOf(b);
			if (idx >= 0)
			{
				blist.removeAt(idx);
				delete b;
			}
			return true;
		}
	}
	return false;
}

bool Bookmarks::remove(QAction *id)
{
	if (bmap.contains(id))
	{
		Bookmark *b = bmap[id];
		bmenu->removeAction(id);
		bmap.remove(id);
		int idx = blist.indexOf(b);
		if (idx >= 0)
		{
			blist.removeAt(idx);
			delete b;
		}
		changed = true;
	}
}

bool Bookmarks::get(QAction *action, Bookmark &b)
{
	if (bmap.contains(action))
	{
		b = *bmap[action];
		return true;
	}
	return false;
}

QList<Bookmark> Bookmarks::get() const
{
	QList<Bookmark> res;
	foreach (Bookmark *b, blist)
		res.push_back(*b);
	return res;
}

bool Bookmarks::exists(const QString &cbname)
{
	foreach (Bookmark *b, blist)
		if (b->getName() == cbname)
			return true;
	return false;
}
